package com.fastbee.xunjian.service;


import com.fastbee.xunjian.domain.XjInspectionNote;

import java.util.List;

/**
 * 巡检注意事项Service接口
 *
 * @author kenlixunjian
 * @date 2023-08-23
 */
public interface IXjInspectionNoteService {
    /**
     * 查询巡检注意事项
     *
     * @param id 巡检注意事项主键
     * @return 巡检注意事项
     */
    public XjInspectionNote selectXjInspectionNoteById(Long id);

    /**
     * 查询巡检注意事项列表
     *
     * @param XjInspectionNote 巡检注意事项
     * @return 巡检注意事项集合
     */
    public List<XjInspectionNote> selectXjInspectionNoteList(XjInspectionNote XjInspectionNote);

    /**
     * 新增巡检注意事项
     *
     * @param XjInspectionNote 巡检注意事项
     * @return 结果
     */
    public int insertXjInspectionNote(XjInspectionNote XjInspectionNote);

    /**
     * 修改巡检注意事项
     *
     * @param XjInspectionNote 巡检注意事项
     * @return 结果
     */
    public int updateXjInspectionNote(XjInspectionNote XjInspectionNote);

    /**
     * 批量删除巡检注意事项
     *
     * @param ids 需要删除的巡检注意事项主键集合
     * @return 结果
     */
    public int deleteXjInspectionNoteByIds(Long[] ids);

    /**
     * 删除巡检注意事项信息
     *
     * @param id 巡检注意事项主键
     * @return 结果
     */
    public int deleteXjInspectionNoteById(Long id);
}
